@@ -38,10 +38,7 @@
 SIMPLE_CMD(cmd_next, mpd_run_next, 1)
 SIMPLE_CMD(cmd_prev, mpd_run_previous, 1)
 SIMPLE_CMD(cmd_stop, mpd_run_stop, 1)
-
-#if LIBMPDCLIENT_CHECK_VERSION(2,4,0)
 SIMPLE_CMD(cmd_clearerror, mpd_run_clearerror, 1)
-#endif
 
 SIMPLE_ONEARG_CMD(cmd_save, mpd_run_save, 0)
 SIMPLE_ONEARG_CMD(cmd_rm, mpd_run_rm, 0)
@@ -299,8 +296,6 @@ cmd_disable(gcc_unused int argc, char **argv, struct mpd_connection *conn)
 			      mpd_send_enable_output);
 }
 
-#if LIBMPDCLIENT_CHECK_VERSION(2,9,0)
-
 int
 cmd_toggle_output(int argc, char **argv, struct mpd_connection *conn)
 {
@@ -308,8 +303,6 @@ cmd_toggle_output(int argc, char **argv, struct mpd_connection *conn)
 			      mpd_send_toggle_output);
 }
 
-#endif
-
 int
 cmd_play(int argc, char **argv, struct mpd_connection *conn)
 {
@@ -335,15 +328,22 @@ cmd_play(int argc, char **argv, struct mpd_connection *conn)
 }
 
 static int
-find_songname_id(struct mpd_connection *conn, const char *s)
+find_songname_id(struct mpd_connection *conn, int argc, char **argv)
 {
 	int res = -1;
 
 	mpd_search_queue_songs(conn, false);
 
-	const char *pattern = charset_to_utf8(s);
-	mpd_search_add_any_tag_constraint(conn, MPD_OPERATOR_DEFAULT,
-					       pattern);
+	if (argc == 1) {
+		const char *pattern = charset_to_utf8(argv[0]);
+		mpd_search_add_any_tag_constraint(conn, MPD_OPERATOR_DEFAULT,
+						  pattern);
+	} else {
+		int n = add_constraints(argc, argv, conn);
+		if (n < 0)
+			return -2;
+	}
+
 	mpd_search_commit(conn);
 
 	struct mpd_song *song = mpd_recv_song(conn);
@@ -361,10 +361,12 @@ find_songname_id(struct mpd_connection *conn, const char *s)
 int
 cmd_searchplay(gcc_unused int argc, char **argv, struct mpd_connection *conn)
 {
-	int id = find_songname_id(conn, argv[0]);
+	int id = find_songname_id(conn, argc, argv);
+	if (id == -2)
+		/* add_constraints() has failed */
+		return -1;
 	if (id < 0)
-		DIE("error: playlist contains no song with that name: %s\n",
-		    argv[0]);
+		DIE("error: playlist contains no matching song\n");
 
 	if (!mpd_run_play_id(conn, id))
 		printErrorAndExit(conn);
@@ -541,7 +543,7 @@ cmd_listall(int argc, char **argv, struct mpd_connection *conn)
 			if (!mpd_send_list_all_meta(conn, tmp))
 				printErrorAndExit(conn);
 
-			print_entity_list(conn, MPD_ENTITY_TYPE_UNKNOWN);
+			print_entity_list(conn, MPD_ENTITY_TYPE_SONG);
 		} else {
 			if (!mpd_send_list_all(conn, tmp))
 				printErrorAndExit(conn);
@@ -724,7 +726,6 @@ cmd_volume(int argc, char **argv, struct mpd_connection *conn)
 	}
 
 	if (ch.is_relative) {
-#if LIBMPDCLIENT_CHECK_VERSION(2,9,0)
 		if (mpd_connection_cmp_server_version(conn, 0, 18, 0) >= 0) {
 			/* MPD 0.18 knows the "volume" command for
 			   relative changes */
@@ -732,7 +733,6 @@ cmd_volume(int argc, char **argv, struct mpd_connection *conn)
 				printErrorAndExit(conn);
 			return 1;
 		}
-#endif
 
 		struct mpd_status *status = getStatus(conn);
 		int old_volume = mpd_status_get_volume(status);
@@ -763,6 +763,24 @@ cmd_pause(gcc_unused int argc, gcc_unused char **argv,
 	return 1;
 }
 
+int
+cmd_pause_if_playing(gcc_unused int argc, gcc_unused char **argv,
+		     struct mpd_connection *conn)
+{
+	struct mpd_status *status = getStatus(conn);
+	int ret = 1;
+
+	if (mpd_status_get_state(status) != MPD_STATE_PLAY) {
+		ret = -127;
+	} else {
+		cmd_pause(0, NULL, conn);
+	}
+
+	mpd_status_free(status);
+
+	return ret;
+}
+
 static int
 bool_cmd(int argc, char **argv, struct mpd_connection *conn,
 	 bool (*get_mode)(const struct mpd_status *status),
